@@ -1,14 +1,7 @@
 import elftools.dwarf.structs
-import elftools.dwarf.die
-import elftools.dwarf.compileunit
-from elftools.construct import Struct, Enum, If, Switch
-from elftools.dwarf.enums import *
-from elftools.common.construct_utils import RepeatUntilExcluding
-from elftools.common.utils import struct_parse
-from elftools.dwarf.die import AttributeValue
-from elftools.construct.adapters import ExprAdapter
 from elftools.construct.macros import Array
-
+import elftools.dwarf.locationlists
+from elftools.dwarf.dwarf_util import DWARFError
 
 # Fixes to pyelftools that are not in the released version yet
 # Not sure about form_indirect, no binaries.
@@ -20,4 +13,11 @@ def monkeypatch():
         self.Dwarf_dw_form['DW_FORM_data16'] = Array(16, self.Dwarf_uint8(''))
             
     elftools.dwarf.structs.DWARFStructs._create_dw_form_base = elftools.dwarf.structs.DWARFStructs._create_dw_form
-    elftools.dwarf.structs.DWARFStructs._create_dw_form = _create_dw_form_ex
\ No newline at end of file
+    elftools.dwarf.structs.DWARFStructs._create_dw_form = _create_dw_form_ex
+
+    def get_location_list_at_offset_ex(self, offset, die=None):
+        if die is None:
+            raise DWARFError("For this binary, \"die\" needs to be provided")
+        section = self._loclists if die.cu.header.version >= 5 else self._loc
+        return section.get_location_list_at_offset(offset, die)
+    elftools.dwarf.locationlists.LocationListsPair.get_location_list_at_offset = get_location_list_at_offset_ex
\ No newline at end of file
